@@ -12,7 +12,7 @@ class Authorization:
     """ Предоставляет возможность авторизации в Полиматике """
 
     def login(self, user_name: str, url: str, server_codes: Dict, timeout: float, language: str, suffixes_url: List,
-              password: str = None) -> Tuple:
+              is_guest: bool, password: str) -> Tuple:
         """
         Авторизация (парольная/беспарольная).
         :param user_name: имя пользователя.
@@ -20,6 +20,7 @@ class Authorization:
         :param server_codes: значение файла "server_codes.json", хранящего коды команд и их состояний.
         :param timeout: тайм-аут выполнения запроса авторизации.
         :param language: язык локализации; возможны значения: "en" / "ru" / "de" / "fr".
+        :param is_guest: флаг гостевого пользователя при беспарольной авторизации.
         :param password: пароль пользователя; может быть не задан (None).
         :param suffixes_url: список возможных суффиксов URL-адреса стенда Полиматики.
         :return: (Tuple) идентификатор сессии, uuid, полная версия Полиматики.
@@ -39,8 +40,9 @@ class Authorization:
 
         # для авторизации без пароля формируем id сессии для беспарольного пользователя
         if password is None:
-            login_url = "{}login".format(url)
-            r = requests.get(url=login_url, params={"login": user_name})
+            is_guest_str = self._check_guest(is_guest)
+            login_url = "{}login?login={}&is_guest={}".format(url, user_name, is_guest_str)
+            r = requests.get(url=login_url, params={"login": user_name, "is_guest": is_guest})
             if not r.ok:
                 msg = 'Stand "{}" not supporting non-password authorization. Please, specify the password! ' \
                     'Details: Code: {}, Reason: "{}", Text: {}'.format(
@@ -145,8 +147,18 @@ class Authorization:
         :param locale: (str) пользовательское значение языка.
         """
         if language not in ("ru", "en"):
-            msg = 'Invalid language! Expected: "ru"/"en", found: "{}"'.format(language)
-            raise AuthError(msg)
+            error_msg = 'Invalid language! Expected: "ru"/"en", found: "{}"'.format(language)
+            raise AuthError(error_msg)
+
+    def _check_guest(self, guest_param: bool) -> str:
+        """
+        Проверка параметра "is_guest": должны быть только булевы значения. В противном случае сгенерируется ошибка.
+        Возвращает строковое значение параметра.
+        """
+        if not isinstance(guest_param, bool):
+            error_msg = 'Invalid "is_guest" param! Expected: True/False, found: "{}"'.format(guest_param)
+            raise AuthError(error_msg)
+        return 'true' if guest_param else 'false'
 
     def _get_prepare_query(self, query: Dict) -> str:
         """
