@@ -7,7 +7,7 @@
 import logging
 import time
 from datetime import date, datetime
-from typing import Any, Union, Callable
+from typing import Any, Union, Callable, Tuple
 from .consts import TYPES_MAP, business_logic, time_type
 from ..exceptions import *
 
@@ -272,7 +272,7 @@ def timing(func: Callable) -> Callable:
     return timing_wrap
 
 
-def raise_exception(bl_instance: business_logic):
+def raise_exception(bl_instance: business_logic) -> Callable:
     """
     Обёртка над функцией-генератором исключений.
     Сделано для того, чтобы каждый раз не передавать в функцию экземпляр класса "BusinessLogic".
