@@ -2,13 +2,14 @@
 # -*- coding: utf-8 -*-
 """ Модуль обработки ошибок из ответа """
 
+from mimetypes import common_types
 from multiprocessing.sharedctypes import Value
 import re
 import requests
 import datetime
 from typing import Dict, Union, Callable
 from .common import datetime_type, \
-    MONTHS, WEEK_DAYS, FUNCS, LOGIC_FUNCS, UPDATE_TYPES, WEEK, UPDATE_PERIOD, INTERVAL_MAP
+    MONTHS, WEEK_DAYS, FUNCS, LOGIC_FUNCS, UPDATE_TYPES, WEEK, UPDATE_PERIOD, INTERVAL_MAP, INTERVAL_BORDERS_DATE_FORMAT
 
 
 def check_types() -> Callable:
@@ -134,10 +135,11 @@ def checks(self, func_name: str, *args):
             raise ValueError("is_visible param can only be boolean: True / False")
         return True
     elif func_name == "sort_measure":
-        is_visible = args[0]
-        if is_visible not in ("ascending", "descending", "off"):
+        sort_type = args[0]
+        common_types = {"off": 0, "ascending": 1, "descending": 2}
+        if sort_type not in common_types:
             raise ValueError('Param "sort_type" can only equals "ascending" or "descending" or "off"!')
-        return True
+        return common_types[sort_type]
     elif func_name == "unfold_all_dims":
         position, level = args[0], args[1]
         # проверка позиции
@@ -328,19 +330,19 @@ def checks(self, func_name: str, *args):
             return True
 
         update_params, file_type, sql_params, user_interval, source_name, cube_name, \
-            time_zones, increment_dim, interval_dim, interval_borders, date_format = args
+            time_zones, increment_dim, interval_dim, interval_borders = args
 
         def check_time(time: str) -> bool:
             """
             Проверка формата времени.
-            Вернёт True, если формат времени задан неправильно, иначе False.
+            Вернёт False, если формат времени задан неправильно, иначе True.
             """
             try:
                 splitted_time = time.split(':')
                 datetime.time(int(splitted_time[0]), int(splitted_time[1]))
             except Exception:
-                return True
-            return False
+                return False
+            return True
 
         def get_date(date: str) -> datetime:
             """
@@ -348,7 +350,7 @@ def checks(self, func_name: str, *args):
             Если преобразование строковой даты по заданному формату невозможно - будет сгенерирована ошибка.
             """
             try:
-                res = datetime.datetime.strptime(date, date_format)
+                res = datetime.datetime.strptime(date, INTERVAL_BORDERS_DATE_FORMAT)
             except ValueError:
                 raise
             return res
@@ -370,20 +372,20 @@ def checks(self, func_name: str, *args):
             schedules = user_schedule if isinstance(user_schedule, list) else [user_schedule]
             for schedule in schedules:
                 # проверка времени
-                if "time" in schedule and check_time(schedule["time"]):
+                if "time" in schedule and not check_time(schedule["time"]):
                     raise ValueError('Time "{}" has wrong format!'.format(schedule["time"]))
                 # проверка часовой зоны
                 if "time_zone" in schedule and schedule["time_zone"] not in time_zones:
                     raise ValueError('Time zone "{}" does not exist!'.format(schedule["time_zone"]))
                 # проверка периода
                 if "type" in schedule and schedule["type"] not in UPDATE_PERIOD:
-                    raise ValueError('Нет периода: "{}"!'.format(schedule["type"]))
+                    raise ValueError('Update period "{}" not found!'.format(schedule["type"]))
                 # проверка дня недели
                 if "week_day" in schedule and schedule["week_day"] not in WEEK:
-                    raise ValueError('Неверный день недели: "{}"!'.format(schedule["week_day"]))
+                    raise ValueError('Wrong day of week: "{}"!'.format(schedule["week_day"]))
                 # проверка номера дня в месяце
-                if "day" in schedule and schedule["day"] > 31:
-                    raise ValueError('Неверное число месяца: "{}"!'.format(schedule["day"]))
+                if "day" in schedule and (schedule["day"] < 0 or schedule["day"] > 31):
+                    raise ValueError('Wrong date in month: "{}"!'.format(schedule["day"]))
 
         # проверки инкрементального обновления
         if update_type == "инкрементальное" and not increment_dim:
@@ -425,6 +427,87 @@ def checks(self, func_name: str, *args):
 
         self.func_name = 'create_sphere'
         return True
+    elif func_name == "update_cube":
+        cube_name, cubes_list, \
+            update_params, user_interval, increment_dim, interval_dim, interval_borders, time_zones = args
+
+        def check_time(time: str) -> bool:
+            """
+            Проверка формата времени.
+            Вернёт False, если формат времени задан неправильно, иначе True.
+            """
+            try:
+                splitted_time = time.split(':')
+                datetime.time(int(splitted_time[0]), int(splitted_time[1]))
+            except Exception:
+                return False
+            return True
+
+        def get_date(date: str) -> datetime:
+            """
+            Возвращает дату объекта datetime по строковому формату даты.
+            Если преобразование строковой даты по заданному формату невозможно - будет сгенерирована ошибка.
+            """
+            try:
+                res = datetime.datetime.strptime(date, INTERVAL_BORDERS_DATE_FORMAT)
+            except ValueError:
+                raise
+            return res
+
+        # проверка куба на существование
+        try:
+            cube_id = self.h.get_cube_id(cubes_list, cube_name)
+        except ValueError as ex:
+            raise ValueError(ex)
+
+        # проверка заданного типа обновления и его параметров
+        update_type = update_params.get("type")
+        if update_type not in UPDATE_TYPES:
+            raise ValueError('Unknown update type: {}'.format(update_type))
+        if update_type != "ручное":
+            user_schedule = update_params.get("schedule", list())
+            schedules = user_schedule if isinstance(user_schedule, list) else [user_schedule]
+            for schedule in schedules:
+                # проверка времени
+                if "time" in schedule and not check_time(schedule["time"]):
+                    raise ValueError('Time "{}" has wrong format!'.format(schedule["time"]))
+                # проверка часовой зоны
+                if "time_zone" in schedule and schedule["time_zone"] not in time_zones:
+                    raise ValueError('Time zone "{}" does not exist!'.format(schedule["time_zone"]))
+                # проверка периода
+                if "type" in schedule and schedule["type"] not in UPDATE_PERIOD:
+                    raise ValueError('Update period "{}" not found!'.format(schedule["type"]))
+                # проверка дня недели
+                if "week_day" in schedule and schedule["week_day"] not in WEEK:
+                    raise ValueError('Wrong day of week: "{}"!'.format(schedule["week_day"]))
+                # проверка номера дня в месяце
+                if "day" in schedule and (schedule["day"] < 0 or schedule["day"] > 31):
+                    raise ValueError('Wrong date in month: "{}"!'.format(schedule["day"]))
+
+        # проверки инкрементального обновления
+        if update_type == "инкрементальное" and not increment_dim:
+            raise ValueError('Please enter "increment_dim" param!')
+
+        # проверки интервального обновления
+        if update_type == "интервальное":
+            if not interval_dim:
+                raise ValueError('Please enter "interval_dim" param!')
+            if user_interval not in INTERVAL_MAP:
+                raise ValueError('No such interval: "{}"'.format(user_interval))
+            if user_interval == "с указанной даты":
+                if len(interval_borders) < 1:
+                    raise ValueError(
+                        'For the current update interval parameter "interval_borders" must have at least one element!')
+                _ = get_date(interval_borders[0])
+            if user_interval == "с и по указанную дату":
+                if len(interval_borders) < 2:
+                    raise ValueError(
+                        'For the current update interval parameter "interval_borders" must have at least two elements!')
+                if get_date(interval_borders[0]) > get_date(interval_borders[1]):
+                    raise ValueError('Start date must be greater than end date!')
+
+        self.func_name = 'update_cube'
+        return cube_id
     elif func_name == "execute_olap_command":
         if self.multisphere_module_id == "":
             raise ValueError("First create cube and get data from it!")
