@@ -91,6 +91,99 @@ class BaseGraph():
                 params = [axis, start, end, step]
                 raise ValueError("Axis {} frequency must be set in interval [{}, {}] with step {}!".format(*params))
 
+    def _check_division_value(self, value: str):
+        """
+        Проверка параметра "Цена деления" на возможные значения.
+        :param value: (str) значение параметра "Цена деления".
+        """
+        possible_values = ("no", "hundreds", "thousands", "millions", "billions", "trillions")
+        if value not in possible_values:
+            raise ValueError('Param "division_value" must have one of values: {}, found: "{}"'.format(
+                str(possible_values)[1:-1], value))
+
+    def _get_labels_settings_two_axis_type(self, **kwargs) -> dict:
+        """
+        Получение настроек графика по параметру labels.
+        Для типов графиков:
+        [1, "lines"], [2, "cylinders"], [3, "cumulative_cylinders"], [4, "areas"],
+        [5, "cumulative_areas"], [8, "circles"], [9, "circles_series"], [11, "pools"], [13, "corridors"].
+        :return:
+            Для версии Полиматики 5.6:
+                {
+                    'axisNotesPeriodX': <value>,
+                    'axisNotesPeriodY': <value>,
+                    'axisXShortFormat': <value>
+                }
+            Для версии Полиматики 5.7:
+                {
+                    'axisNotesPeriodTitle': {'axisNotesPeriodX': <value>, 'axisNotesPeriodY': <value>},
+                    'divisionPrice': <value>
+                }
+        """
+        values_dict = {'OX': self.labels.get('OX', 10), 'OY': self.labels.get('OY', 10)}
+        self.check_frequency_axis_5_30_5(values_dict)
+
+        result_labels = dict()
+        if self.base_bl.polymatica_version == '5.6':
+            result_labels.update({
+                "axisNotesPeriodX": values_dict.get('OX'),
+                "axisNotesPeriodY": values_dict.get('OY')
+            })
+            if kwargs.get("add_short_format", True):
+                short_format = self.labels.get('short_format', False)
+                if not self.check_bool(short_format):
+                    raise ValueError('Param "short_format" must be bool type!')
+                result_labels.update({"axisXShortFormat": short_format})
+        elif self.base_bl.polymatica_version == '5.7':
+            division_value = self.labels.get('division_value', 'no')
+            self._check_division_value(division_value)
+            result_labels.update({
+                "axisNotesPeriodTitle": {
+                    "axisNotesPeriodX": values_dict.get('OX'),
+                    "axisNotesPeriodY": values_dict.get('OY')
+                },
+                "divisionPrice": division_value
+            })
+
+        return result_labels
+
+    def _get_labels_settings_two_three_type(self, **kwargs) -> dict:
+        """
+        Получение настроек графика по параметру labels.
+        Для типов графиков: [10, "balls"], [12, "3d_pools"].
+        :return:
+            {
+                "axisNotesPeriodX": <value>,
+                "axisNotesPeriodY": <value>,
+                "axisNotesPeriodZ": <value>
+            }
+        """
+        default_axis_value = 2.5
+        values_dict = {
+            'OX': self.labels.get('OX', default_axis_value),
+            'OY': self.labels.get('OY', default_axis_value),
+            'OZ': self.labels.get('OZ', default_axis_value)
+        }
+        self.check_frequency_axis_1_10_05(values_dict)
+        return {
+            "axisNotesPeriodX": values_dict.get('OX'),
+            "axisNotesPeriodY": values_dict.get('OY'),
+            "axisNotesPeriodZ": values_dict.get('OZ')
+        }
+
+    def get_labels_settings(self, _type: str, **kwargs) -> dict:
+        """
+        Получение настроек подписи к графику (параметр labels).
+        :param _type: (str) тип подписей графиков, варианты:
+            "two_axis" - две оси координат, "three_axis" - три оси координат.
+        :return: (Dict) настройки подписи к графику.
+        """
+        if _type == "two_axis":
+            return self._get_labels_settings_two_axis_type(**kwargs)
+        elif _type == "three_axis":
+            return self._get_labels_settings_two_three_type(**kwargs)
+        raise NotImplementedError('Type "{}" is not implemented!'.format(_type))
+
     def check_olap_configuration(self, left_dims_count: int, top_dims_count: int, fact_count: int, marked: bool):
         """
         Сверка текущей конфигурации OLAP-модуля на соответствие заданному типу графика.
@@ -271,15 +364,18 @@ class BaseGraph():
             # конфигурация графика
             "plotData": {
                 self.graph_type: {
-                    # тут будет прописан конфиг, сформированный на основе настроек, заданных пользователем
+                    # для каждого типа графика тут будет прописан конфиг,
+                    # сформированный на основе пользовательских настроек
                     "config": {
                     },
-                    # в этом блоке задаём имя графику; остальное неизвестно, для чего, но нужно
+                    # в этом блоке описываем состояние графика
                     "state": {
+                        # цвета, используемые при построении
                         "colors": {
-                            "facts": {}
                         },
+                        # название графика
                         "title": self.graph_name,
+                        # масштабирование
                         "zoom": {
                             "k": 1,
                             "x": 0,
